#!/usr/bin/env python
import astropy.io.fits as pyfits
import sys
import time


def mjd2jd(m):
    return m + 2400000.5


def load_FT2(orbname):
    # Load data from FT2 FITS file
    hdulist = pyfits.open(orbname)
    ft1hdr = hdulist[1].header
    ft1dat = hdulist[1].data
    if ft1hdr["TIMESYS"] != "TT":
        print("# !!!!!!!!!!!!!!!!!!!!!!!!!!!!")
        print("# !!!!!!!!! WARNING !!!!!!!!!! TIMESYS is NOT TT!")
        print("# !!!!!!!!!!!!!!!!!!!!!!!!!!!!")
        time.sleep(5)
    # Collect TIMEZERO and MJDREF
    try:
        TIMEZERO = ft1hdr["TIMEZERO"]
    except KeyError:
        TIMEZERO = ft1hdr["TIMEZERI"] + ft1hdr["TIMEZERF"]
    try:
        MJDREF = ft1hdr["MJDREF"]
    except KeyError:
        # Here I have to work around an issue where the MJDREFF key is stored
        # as a string in the header and uses the "1.234D-5" syntax for floats, which
        # is not supported by Python
        MJDREF = ft1hdr["MJDREFI"]
        if type(ft1hdr["MJDREFF"]) == float:
            MJDREF += ft1hdr["MJDREFF"]
        else:
            MJDREF += float(ft1hdr["MJDREFF"].replace("D", "E"))
    mjds_tt = ft1dat.field("START") / 86400.0 + MJDREF + TIMEZERO

    sc_pos = ft1dat.field("SC_POSITION")
    try:
        sc_vel = ft1dat.field("SC_VELOCITY")
    except:
        sc_vel = None
    return mjds_tt, sc_pos, sc_vel


fname = sys.argv[1]
outfile = open("FT2.in", "w")

mjds_tt, sc_pos, sc_vel = load_FT2(fname)

if sc_vel is None:
    for i in range(len(mjds_tt)):
        print(
            "JD %.12f TDT, %.6f, %.6f, %.6f, %.6f, %.6f, %.6f"
            % (mjd2jd(mjds_tt[i]), sc_pos[i, 0], sc_pos[i, 1], sc_pos[i, 2], 0, 0, 0),
            file=outfile,
        )
else:
    for i in range(len(mjds_tt)):
        print(
            "JD %.12f TDT, %.6f, %.6f, %.6f, %.6f, %.6f, %.6f"
            % (
                mjd2jd(mjds_tt[i]),
                sc_pos[i, 0],
                sc_pos[i, 1],
                sc_pos[i, 2],
                sc_vel[i, 0],
                sc_vel[i, 1],
                sc_vel[i, 2],
            ),
            file=outfile,
        )
